..
   This is an autogenerated file from processors.rst

avatars.processors.ProportionProcessor
======================================

.. autoclass:: avatars.processors.ProportionProcessor
   :members: